@@ -5,6 +5,8 @@ from functools import partial
 from pyinels.device import Device
 
 from pyinels.const import (
+    NAME,
+    VERSION,
     ATTR_DOWN,
     ATTR_GROUP,
     ATTR_ID,
@@ -30,7 +32,6 @@ from xmlrpc.client import ServerProxy
 
 _LOGGER = logging.getLogger(__name__)
 
-
 class Api:
     """Class of iNels BUS."""
 
@@ -42,6 +43,9 @@ class Api:
         self.__proxy = None
         self.__devices = None
 
+        self.package_name = NAME
+        self.package_version = VERSION
+
     @property
     def proxy(self):
         """Proxy of the bus server."""
@@ -78,6 +82,12 @@ class Api:
         """Check connection iNels BUS with ping."""
         return self.proxy.ping()
 
+    def get_package_name(self):
+        return self.package_name
+
+    def get_package_version(self):
+        return self.package_version
+
     def getPlcIp(self):
         """Get Ip address of PLC."""
         return self.proxy.getPlcIP()
